@@ -1,23 +1,24 @@
 /*
- *	wmnut : rcfiles.c
+ * rcfiles.c: usefull functions to deal with parameters from rc files
+ * or command line
  *
- *  These are usefull functions to deal with parameters from rc files  
- *  or command line
+ * Copyright (C)
+ *   2002 - 2012  Arnaud Quette <arnaud.quette@free.fr>
  *
- * 	This program is free software; you can redistribute it and/or modify
- * 	it under the terms of the GNU General Public License as published by
- * 	the Free Software Foundation; either version 2, or (at your option)
- * 	any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
  *
- * 	This program is distributed in the hope that it will be useful,
- * 	but WITHOUT ANY WARRANTY; without even the implied warranty of
- * 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * 	GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * 	You should have received a copy of the GNU General Public License
- * 	along with this program (see the file COPYING); if not, write to the
- * 	Free Software Foundation, Inc.,
- * 	59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program (see the file COPYING); if not, write to the
+ * Free Software Foundation, Inc.,
+ * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
  */
 
@@ -33,7 +34,7 @@
 
 
 /*******************************************************************************\
-|* AddRcKey		  						        |
+|* AddRcKey                                                                     |
 \*******************************************************************************/
 void AddRcKey(rckeys *key, const char *label, int type, void *var) {
 
@@ -198,8 +199,8 @@ void ParseCMDLine(int argc, char *argv[])
 					*p = '\0';
 				LAlertRate = atof(optarg);
 				CAlertRate = atof(p+1);
-				printf ("option A : valeur LAlertRate = %d(%s), CAlertRate = %d(%s)\n",
-					LAlertRate, CAlertRate, optarg, (p+1));
+				printf ("option A : valeur LAlertRate = %f(%s), CAlertRate = %f(%s)\n",
+					LAlertRate, optarg, CAlertRate, (p+1));
 				break;
 			case 'b': 
 				BlinkRate = atof(optarg);
@@ -219,10 +220,9 @@ void ParseCMDLine(int argc, char *argv[])
 			case 'v':   
 				printf("\nThis is wmnut version: %s\n", VERSION);
 				printf("\nCopyright 2001-2003 Arnaud Quette <%s>\n", PACKAGE_BUGREPORT);
-				printf("This program is Sponsored by MGE UPS SYSTEMS (http://www.mgeups.com/opensource)\n");
 				printf("\nComplete documentation for WMNUT should be found on this system using\n");
 				printf("`man wmnut' or `wmnut -h'.  If you have access to the Internet, point\n");
-				printf("your browser at http://wmnut.tuxfamily.org, the WMNUT Home Page.\n\n");
+				printf("your browser at http://wmnut.mgeops.org, the WMNUT Home Page.\n\n");
 				exit(1);
 			case 'w': 
 				WithDrawn = 0; /* not in default withdrawn mode, so in windowed mode */
@@ -237,7 +237,7 @@ void ParseCMDLine(int argc, char *argv[])
 			case 'h':
 			default:  
 				printf("\n%s version: %s\n", PACKAGE, VERSION);
-				printf("Usage: %s [arguments]\n\n" PACKAGE);
+				printf("Usage: %s [arguments]\n\n", PACKAGE_NAME);
 				printf("-A <T1,T2>\tSend messages to users terminals when Low and critical.\n");
 				printf("             \tT1 is seconds between messages when Low.\n"); 
 				printf("             \tT2 is seconds between messages when Critical.\n");
